==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/services/ec2/CfnTransitGatewayRouteTablePropagationProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `AWS::EC2::TransitGatewayRouteTablePropagation`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:17.038Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_ec2.CfnTransitGatewayRouteTablePropagationProps")
@software.amazon.jsii.Jsii.Proxy(CfnTransitGatewayRouteTablePropagationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnTransitGatewayRouteTablePropagationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * `AWS::EC2::TransitGatewayRouteTablePropagation.TransitGatewayAttachmentId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTransitGatewayAttachmentId();

    /**
     * `AWS::EC2::TransitGatewayRouteTablePropagation.TransitGatewayRouteTableId`.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTransitGatewayRouteTableId();

    /**
     * @return a {@link Builder} of {@link CfnTransitGatewayRouteTablePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnTransitGatewayRouteTablePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnTransitGatewayRouteTablePropagationProps> {
        private java.lang.String transitGatewayAttachmentId;
        private java.lang.String transitGatewayRouteTableId;

        /**
         * Sets the value of {@link CfnTransitGatewayRouteTablePropagationProps#getTransitGatewayAttachmentId}
         * @param transitGatewayAttachmentId `AWS::EC2::TransitGatewayRouteTablePropagation.TransitGatewayAttachmentId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transitGatewayAttachmentId(java.lang.String transitGatewayAttachmentId) {
            this.transitGatewayAttachmentId = transitGatewayAttachmentId;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteTablePropagationProps#getTransitGatewayRouteTableId}
         * @param transitGatewayRouteTableId `AWS::EC2::TransitGatewayRouteTablePropagation.TransitGatewayRouteTableId`. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transitGatewayRouteTableId(java.lang.String transitGatewayRouteTableId) {
            this.transitGatewayRouteTableId = transitGatewayRouteTableId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnTransitGatewayRouteTablePropagationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnTransitGatewayRouteTablePropagationProps build() {
            return new Jsii$Proxy(transitGatewayAttachmentId, transitGatewayRouteTableId);
        }
    }

    /**
     * An implementation for {@link CfnTransitGatewayRouteTablePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnTransitGatewayRouteTablePropagationProps {
        private final java.lang.String transitGatewayAttachmentId;
        private final java.lang.String transitGatewayRouteTableId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.transitGatewayAttachmentId = software.amazon.jsii.Kernel.get(this, "transitGatewayAttachmentId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.transitGatewayRouteTableId = software.amazon.jsii.Kernel.get(this, "transitGatewayRouteTableId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String transitGatewayAttachmentId, final java.lang.String transitGatewayRouteTableId) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.transitGatewayAttachmentId = java.util.Objects.requireNonNull(transitGatewayAttachmentId, "transitGatewayAttachmentId is required");
            this.transitGatewayRouteTableId = java.util.Objects.requireNonNull(transitGatewayRouteTableId, "transitGatewayRouteTableId is required");
        }

        @Override
        public final java.lang.String getTransitGatewayAttachmentId() {
            return this.transitGatewayAttachmentId;
        }

        @Override
        public final java.lang.String getTransitGatewayRouteTableId() {
            return this.transitGatewayRouteTableId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("transitGatewayAttachmentId", om.valueToTree(this.getTransitGatewayAttachmentId()));
            data.set("transitGatewayRouteTableId", om.valueToTree(this.getTransitGatewayRouteTableId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_ec2.CfnTransitGatewayRouteTablePropagationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnTransitGatewayRouteTablePropagationProps.Jsii$Proxy that = (CfnTransitGatewayRouteTablePropagationProps.Jsii$Proxy) o;

            if (!transitGatewayAttachmentId.equals(that.transitGatewayAttachmentId)) return false;
            return this.transitGatewayRouteTableId.equals(that.transitGatewayRouteTableId);
        }

        @Override
        public final int hashCode() {
            int result = this.transitGatewayAttachmentId.hashCode();
            result = 31 * result + (this.transitGatewayRouteTableId.hashCode());
            return result;
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/ec2/CfnTransitGatewayRouteTablePropagationProps.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Properties for defining a `CfnTransitGatewayRouteTablePropagation`.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.ec2.*;
 * CfnTransitGatewayRouteTablePropagationProps cfnTransitGatewayRouteTablePropagationProps = CfnTransitGatewayRouteTablePropagationProps.builder()
 *         .transitGatewayAttachmentId("transitGatewayAttachmentId")
 *         .transitGatewayRouteTableId("transitGatewayRouteTableId")
 *         .build();
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:09.198Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_ec2.CfnTransitGatewayRouteTablePropagationProps")
@software.amazon.jsii.Jsii.Proxy(CfnTransitGatewayRouteTablePropagationProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnTransitGatewayRouteTablePropagationProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The ID of the attachment.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTransitGatewayAttachmentId();

    /**
     * The ID of the propagation route table.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getTransitGatewayRouteTableId();

    /**
     * @return a {@link Builder} of {@link CfnTransitGatewayRouteTablePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnTransitGatewayRouteTablePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnTransitGatewayRouteTablePropagationProps> {
        java.lang.String transitGatewayAttachmentId;
        java.lang.String transitGatewayRouteTableId;

        /**
         * Sets the value of {@link CfnTransitGatewayRouteTablePropagationProps#getTransitGatewayAttachmentId}
         * @param transitGatewayAttachmentId The ID of the attachment. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transitGatewayAttachmentId(java.lang.String transitGatewayAttachmentId) {
            this.transitGatewayAttachmentId = transitGatewayAttachmentId;
            return this;
        }

        /**
         * Sets the value of {@link CfnTransitGatewayRouteTablePropagationProps#getTransitGatewayRouteTableId}
         * @param transitGatewayRouteTableId The ID of the propagation route table. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder transitGatewayRouteTableId(java.lang.String transitGatewayRouteTableId) {
            this.transitGatewayRouteTableId = transitGatewayRouteTableId;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnTransitGatewayRouteTablePropagationProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnTransitGatewayRouteTablePropagationProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnTransitGatewayRouteTablePropagationProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnTransitGatewayRouteTablePropagationProps {
        private final java.lang.String transitGatewayAttachmentId;
        private final java.lang.String transitGatewayRouteTableId;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.transitGatewayAttachmentId = software.amazon.jsii.Kernel.get(this, "transitGatewayAttachmentId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.transitGatewayRouteTableId = software.amazon.jsii.Kernel.get(this, "transitGatewayRouteTableId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.transitGatewayAttachmentId = java.util.Objects.requireNonNull(builder.transitGatewayAttachmentId, "transitGatewayAttachmentId is required");
            this.transitGatewayRouteTableId = java.util.Objects.requireNonNull(builder.transitGatewayRouteTableId, "transitGatewayRouteTableId is required");
        }

        @Override
        public final java.lang.String getTransitGatewayAttachmentId() {
            return this.transitGatewayAttachmentId;
        }

        @Override
        public final java.lang.String getTransitGatewayRouteTableId() {
            return this.transitGatewayRouteTableId;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("transitGatewayAttachmentId", om.valueToTree(this.getTransitGatewayAttachmentId()));
            data.set("transitGatewayRouteTableId", om.valueToTree(this.getTransitGatewayRouteTableId()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_ec2.CfnTransitGatewayRouteTablePropagationProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnTransitGatewayRouteTablePropagationProps.Jsii$Proxy that = (CfnTransitGatewayRouteTablePropagationProps.Jsii$Proxy) o;

            if (!transitGatewayAttachmentId.equals(that.transitGatewayAttachmentId)) return false;
            return this.transitGatewayRouteTableId.equals(that.transitGatewayRouteTableId);
        }

        @Override
        public final int hashCode() {
            int result = this.transitGatewayAttachmentId.hashCode();
            result = 31 * result + (this.transitGatewayRouteTableId.hashCode());
            return result;
        }
    }
}
